local proto_struct =
    [[
    # 房间玩家信息
    .DataRoomPlayer {
        playerInfo 0: DataUserBaseInfo      # 玩家信息
        seatId 1: integer                   # 位置ID
        status 2: integer                   # 状态 1:准备
    }

    # 房间信息
    .DataRoom {
        roomId 0: integer                   # 房间号
        playCount 1:integer                 # 战斗人数
        battleBoxList 2: *integer           # 战斗箱子ID列表
        playerList 3: *DataRoomPlayer       # 房间玩家列表
        status 4: integer                   # 房间状态 0:等待中 1:进行中 2:结束
        createTime 5: integer               # 创建时间
    }

    # 射击结果
    .DataBattleShot {
        itemId 0: integer                   # 中奖饰品ID
        price 1: integer                    # 射击价格
    }
    # 战斗玩家
    .DataBattlePlayer {
        uid 0: integer                      # 玩家ID
        shotList 1: *DataBattleShot         # 射击结果列表
    }
    # 战斗记录
    .DataBattleRecord {
        roomInfo 0: DataRoom
        battleId 1: string
        winUid 2: integer
        battlePlayerList 3: *DataBattlePlayer   # 战斗玩家列表
    }
]]

local proto_c2s =
    [[
        # 获取房间列表
        room_get_info 2600 {
            request {
            }
            response {
                code 0: integer
                roomList 1: *DataRoom       # 房间信息列表
                myRoom 2: DataRoom          # 已进入房间
            }
        }

        # 创建房间
        room_create_room 2601 {
            request {
                playCount 0: integer        # 战斗人数
                battleBoxList 1: *integer   # 战斗箱子ID列表
            }
            response {
                code 0: integer             # 返回结果吗
                room 1: DataRoom            # 房间信息
            }
        }

        # 进入房间
        room_player_enter 2602 {
            request {
                roomId 0: integer           # 房间号码
            }
            response {
                code 0: integer
                room 1: DataRoom            # 房间信息
            }
        }

        # 离开房间
        room_player_leave 2603 {
            request {
            }
            response {
                code 0: integer
            }
        }

        # 解散房间
        room_dismiss_room 2604 {
         request {
            }
            response {
                code 0: integer             # 返回结果码
            }
        }

        # 获取自身房间信息
        room_get_in_room_info 2605 {
            request {
            }
            response {
                code 0: integer             # 返回结果码
                room 1: DataRoom            # 房间信息
            }
        }

        # 所在好友房内玩家操作
        room_player_opt 2606 {
            request {
                optType 0: integer          # 1.坐下，2.站起 ，3.踢参与者（房主强制让坐下的站起）
                targetUid 1: integer        # 被踢的参与者uid（类型3使用）
            }
            response {
                code 0: integer
            }
        }

        # 开始比赛
        room_battle_start 2607 {
            request {
            }
            response {
                code 0: integer
            }
        }

        # 获取房间对战记录列表
        room_get_record_list 2620 {
         request {
            }
            response {
                code 0: integer             # 返回结果码
                list 1: *DataBattleRecord   # 房间对战记录列表
            }
        }

        # 获取房间对战记录列表
        room_get_brilliant_record_list 2621 {
         request {
            }
            response {
                code 0: integer             # 返回结果码
                list 1: *DataBattleRecord   # 房间对战记录列表
            }
        }
]]

local proto_s2c =
    [[
        # 新创建房间推送
        on_room_new 2600 {
            request {
                room 0: DataRoom            # 房间信息
            }
        }

        # 销毁房间
        on_room_destroy 2601 {
            request {
                roomId 0: integer           # 房间ID
            }
        }

        # 所在好友房成员改变推送
        on_room_player_change 2601 {
            request {
                type 0: integer                 # 消息的类型 [房间成员变化 100进入， 101离开， 102坐下 103站起，104强制站起, 105被踢出]
                changeRoomPlayer 1: *DataRoomPlayer # 变化的房间成员
            }
        }
]]

local proto = {
    c2s = proto_struct .. proto_c2s,
    s2c = proto_struct .. proto_s2c
}

return proto
